PartitionHint

Struct PartitionHint 

pub struct PartitionHint {
    pub strategies: Vec<i32>,
    pub count: i64,
}
Enhancement that hints the executor how to partition a relation’s output.

Attach this to any standard relation via register_enhancement to convey partitioning decisions made during planning.

Text Format

=== Plan
Root[result]
  Read[data => col:i64]
    + Enh:PartitionHint[&HASH, count=8]

Fields

strategies: Vec<i32>

The strategies to apply, in order of preference. Each value is the integer representation of PartitionStrategy.

count: i64

Target number of partitions. 0 means “let the executor decide”.

Implementations

Source

impl PartitionHint

pub fn strategies( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<PartitionStrategy>>

Returns an iterator which yields the valid enum values contained in strategies.

pub fn push_strategies(&mut self, value: PartitionStrategy)

Appends the provided enum value to strategies.